rg

package
v0.1.20 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 30, 2026 License: Apache-2.0 Imports: 5 Imported by: 0

Documentation

Overview

Package rg embeds a statically-linked ripgrep binary and exposes a single entry point so the grep tool can always use authoritative rg matching.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Path

func Path() (string, error)

Path returns the filesystem path to the embedded rg binary, extracting it to a temporary file on first call. The caller must not remove the file.

Types

This section is empty.

Jump to